Learn R Programming

CVThresh (version 1.1.0)

cvwavelet.image.after.impute: Cross-Validation Wavelet Shrinkage for two-dimensional data after imputation

Description

This function performs level-dependent cross-validation wavelet shrinkage for two-dimensional data given the cross-validation scheme and imputation values.

Usage

cvwavelet.image.after.impute(images, imagewd, imageimpute,
   cv.index1=cv.index1, cv.index2=cv.index2,
   cv.optlevel=cv.optlevel, cv.tol=cv.tol, cv.maxiter=cv.maxiter,
   filter.number=2, ll=3)

Arguments

images
noisy image
imagewd
two-dimensional wavelet transform
imageimpute
two-dimensional imputed values according to cross-validation scheme
cv.index1
test dataset row index according to cross-validation scheme
cv.index2
test dataset column index according to cross-validation scheme
cv.optlevel
thresholding levels
cv.tol
tolerance for cross-validation
cv.maxiter
maximum iteration for cross-validation
filter.number
specifies the smoothness of wavelet in the decomposition (argument of WaveThresh)
ll
specifies the lowest level to be thresholded

Value

  • Reconstruction of images and thresholding values by level-dependent cross-validation
  • imagecvreconstruction of images
  • cvthreshthresholding values by level-dependent cross-validation

Details

Calculating thresholding values and reconstructing noisy image given cross-validation scheme and imputation.

See Also

cvwavelet.image, cvtype.image, cvimpute.image.by.wavelet.